#!/bin/bash

# -------------------------------------------------------------------------------
# Filename:    check_gtw_route.sh
# Revision:    1.0
# Date:        2008/11/28
# Author:      Luigi Balzano
# Email:       info@sistemistica.it
# Website:     www.sistemistica.it
# Description: Plugin to check if a gateway is used to reach a specified IP
#              destination.
# Notes:       This version uses the "/usr/sbin/route -n get" command
# -------------------------------------------------------------------------------
# Copyright:   2008 (c) Luigi Balzano
# License:     GPL
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# you should have received a copy of the GNU General Public License
# along with this program (or with Nagios); if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA
# -------------------------------------------------------------------------------
# Credits go to Ethan Galstad for coding Nagios
# If any changes are made to this script, please mail me a copy of the changes
#

PROGNAME=`basename $0`
PROGPATH=`echo $0 | /bin/sed -e 's,[\\/][^\\/][^\\/]*$,,'`
REVISION=`echo '$Revision: 1.0 $' | sed -e 's/[^0-9.]//g'`
TIMESTAMP=`date "+%Y-%m-%d %H:%M:%S"`

. $PROGPATH/utils.sh

print_usage() {
        echo "Usage: $PROGNAME -h"
        echo "Usage: $PROGNAME -v"
        echo "Usage: $PROGNAME -d DESTINATION_IP -g EXPECTED_GTW"
}

print_help() {
        print_revision "$PROGNAME" $REVISION
        echo ""
        print_usage
        echo ""
        echo "Plugin to check if a gateway is used to reach a specified IP destination."
        echo ""
        support
}

# No command line arguments are supplied for this script. Print help

if [ "$#" -eq "0" ]; then
        print_usage
        exit $STATE_UNKNOWN
fi

# Print help with --help

if [[ ("$#" -eq "1") && ("$1" = "--help") ]]; then
        print_help
        exit $STATE_UNKNOWN
fi

unset DESTINATION
unset EXPECTED

while getopts "vhd:g:" Option
do
  case $Option in
    h     ) print_help
            exit $STATE_UNKNOWN;;
    v     ) print_revision "$PROGNAME" $REVISION
            exit $STATE_UNKNOWN;;
    d     ) DESTINATION=$OPTARG;;
    g     ) EXPECTED=$OPTARG;;
    *     ) print_usage
            exit $STATE_UNKNOWN;;   # DEFAULT
  esac
done

if [[ (! -n "${DESTINATION}") || (! -n "${EXPECTED}") ]]
  then
        echo "Unspecified argument"
        print_usage
        exit $STATE_UNKNOWN
fi

TRACE=$(/usr/sbin/route -n get ${DESTINATION} 2>&1)
GATEWAY=$(echo "${TRACE}" | awk -F":" '
/gateway/{
  printf("%s\n", $2);
}
' 2>&1)
GATEWAY=${GATEWAY// /} # Remove all spaces

if [ -n "${GATEWAY}" ]
  then
    if [ "${GATEWAY}" = "${EXPECTED}" ]
      then
        echo "OK - Using expected gateway ${GATEWAY} for destination ${DESTINATION}"
        exit $STATE_OK
      else
        echo "CRITICAL - Using wrong gateway ${GATEWAY} (expected is ${EXPECTED}) for destination ${DESTINATION}"
        exit $STATE_CRITICAL
    fi
  else
    echo "CRITICAL - No gateway found for destination ${DESTINATION}"
    exit $STATE_CRITICAL
fi
